@@ -25,6 +25,8 @@
 #'   \item{id}{character, id of this step}
 #' }
 #'
+#' @template sparse-preserve
+#'
 #' @template case-weights-not-supported
 #'
 #' @family row operation steps
@@ -69,12 +71,15 @@
 #'   prep(training = iris)
 #'
 #' tidy(qq_rec, number = 1)
-step_arrange <- function(recipe, ...,
-                         role = NA,
-                         trained = FALSE,
-                         inputs = NULL,
-                         skip = FALSE,
-                         id = rand_id("arrange")) {
+step_arrange <- function(
+  recipe,
+  ...,
+  role = NA,
+  trained = FALSE,
+  inputs = NULL,
+  skip = FALSE,
+  id = rand_id("arrange")
+) {
   inputs <- enquos(...)
 
   add_step(
@@ -120,7 +125,7 @@ bake.step_arrange <- function(object, new_data, ...) {
   dplyr::arrange(new_data, !!!object$inputs)
 }
 
-
+#' @export
 print.step_arrange <-
   function(x, width = max(20, options()$width - 35), ...) {
     title <- "Row arrangement using "
@@ -139,3 +144,8 @@ tidy.step_arrange <- function(x, ...) {
     id = rep(x$id, length(x$inputs))
   )
 }
+
+#' @export
+.recipes_preserve_sparsity.step_arrange <- function(x, ...) {
+  TRUE
+}
