@@ -44,6 +44,8 @@
 #'
 #' The return value is ordered according to the frequency of `columns` entries in the training data set.
 #'
+#' @template sparse-creation
+#'
 #' @template case-weights-unsupervised
 #'
 #' @examplesIf rlang::is_installed("modeldata")
@@ -93,20 +95,22 @@
 #'
 #' dummies_data_color
 step_dummy_extract <-
-  function(recipe,
-           ...,
-           role = "predictor",
-           trained = FALSE,
-           sep = NULL,
-           pattern = NULL,
-           threshold = 0.0,
-           other = "other",
-           naming = dummy_extract_names,
-           levels = NULL,
-           keep_original_cols = FALSE,
-           skip = FALSE,
-           id = rand_id("dummy_extract")) {
-
+  function(
+    recipe,
+    ...,
+    role = "predictor",
+    trained = FALSE,
+    sep = NULL,
+    pattern = NULL,
+    threshold = 0.0,
+    other = "other",
+    naming = dummy_extract_names,
+    levels = NULL,
+    sparse = "auto",
+    keep_original_cols = FALSE,
+    skip = FALSE,
+    id = rand_id("dummy_extract")
+  ) {
     add_step(
       recipe,
       step_dummy_extract_new(
@@ -119,6 +123,7 @@ step_dummy_extract <-
         other = other,
         naming = naming,
         levels = levels,
+        sparse = sparse,
         keep_original_cols = keep_original_cols,
         skip = skip,
         id = id,
@@ -128,8 +133,22 @@ step_dummy_extract <-
   }
 
 step_dummy_extract_new <-
-  function(terms, role, trained, sep, pattern, threshold, other, naming, levels,
-           keep_original_cols, skip, id, case_weights) {
+  function(
+    terms,
+    role,
+    trained,
+    sep,
+    pattern,
+    threshold,
+    other,
+    naming,
+    levels,
+    sparse,
+    keep_original_cols,
+    skip,
+    id,
+    case_weights
+  ) {
     step(
       subclass = "dummy_extract",
       terms = terms,
@@ -141,6 +160,7 @@ step_dummy_extract_new <-
       other = other,
       naming = naming,
       levels = levels,
+      sparse = sparse,
       keep_original_cols = keep_original_cols,
       skip = skip,
       id = id,
@@ -161,6 +181,7 @@ prep.step_dummy_extract <- function(x, training, info = NULL, ...) {
   check_string(x$sep, arg = "sep", allow_null = TRUE)
   check_string(x$pattern, arg = "pattern", allow_null = TRUE)
   check_function(x$naming, arg = "naming", allow_empty = FALSE)
+  check_sparse_arg(x$sparse)
 
   wts <- get_case_weights(info, training)
   were_weights_used <- are_weights_used(wts, unsupervised = TRUE)
@@ -174,7 +195,8 @@ prep.step_dummy_extract <- function(x, training, info = NULL, ...) {
     for (col_name in col_names) {
       elements <- dummy_extract(
         training[[col_name]],
-        sep = x$sep, pattern = x$pattern
+        sep = x$sep,
+        pattern = x$pattern
       )
 
       lvls <- map(elements, unique)
@@ -219,6 +241,7 @@ prep.step_dummy_extract <- function(x, training, info = NULL, ...) {
     other = x$other,
     naming = x$naming,
     levels = levels,
+    sparse = x$sparse,
     keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id,
@@ -239,16 +262,24 @@ bake.step_dummy_extract <- function(object, new_data, ...) {
   for (col_name in col_names) {
     elements <- dummy_extract(
       new_data[[col_name]],
-      sep = object$sep, pattern = object$pattern
+      sep = object$sep,
+      pattern = object$pattern
     )
 
     indicators <- list_to_dummies(
       elements,
       sort(object$levels[[col_name]]),
-      object$other
+      object$other,
+      sparse_is_yes(object$sparse)
     )
-    indicators <- purrr::map(indicators, vec_cast, integer())
-    indicators <- vctrs::vec_cbind(!!!indicators)
+
+    if (sparse_is_yes(object$sparse)) {
+      indicators <- purrr::map(indicators, sparsevctrs::as_sparse_integer)
+    } else {
+      indicators <- purrr::map(indicators, vec_cast, integer())
+    }
+
+    indicators <- tibble::new_tibble(indicators)
 
     ## use backticks for nonstandard factor levels here
     used_lvl <- gsub(paste0("^", col_name), "", colnames(indicators))
@@ -256,7 +287,7 @@ bake.step_dummy_extract <- function(object, new_data, ...) {
 
     indicators <- check_name(indicators, new_data, object, names(indicators))
 
-    new_data <- vec_cbind(new_data, indicators)
+    new_data <- vec_cbind(new_data, indicators, .name_repair = "minimal")
   }
 
   new_data <- remove_original_cols(new_data, object, col_names)
@@ -276,7 +307,7 @@ dummy_extract <- function(x, sep = NULL, pattern = NULL, call = caller_env()) {
   cli::cli_abort("{.arg sep} or {.arg pattern} must be specified.", call = call)
 }
 
-list_to_dummies <- function(x, dict, other = "other") {
+list_to_dummies <- function(x, dict, other = "other", sparse = FALSE) {
   i <- rep(seq_along(x), lengths(x))
   j <- match(unlist(x), dict)
 
@@ -284,22 +315,36 @@ list_to_dummies <- function(x, dict, other = "other") {
   j[is.na(j)] <- length(dict)
 
   out <- Matrix::sparseMatrix(
-    i = i, j = j,
+    i = i,
+    j = j,
     dims = c(length(x), length(dict)),
     x = 1
   )
 
   out@Dimnames[[2]] <- dict
-  out <- as.matrix(out)
-  tibble::as_tibble(out)
+
+  if (sparse) {
+    out <- sparsevctrs::coerce_to_sparse_tibble(out)
+  } else {
+    out <- as.matrix(out)
+    out <- tibble::as_tibble(out)
+  }
+
+  out
 }
 
 #' @export
 print.step_dummy_extract <-
   function(x, width = max(20, options()$width - 20), ...) {
     title <- "Extract patterns from "
-    print_step(names(x$levels), x$terms, x$trained, title, width,
-               case_weights = x$case_weights)
+    print_step(
+      names(x$levels),
+      x$terms,
+      x$trained,
+      title,
+      width,
+      case_weights = x$case_weights
+    )
     invisible(x)
   }
 
@@ -308,7 +353,7 @@ print.step_dummy_extract <-
 tidy.step_dummy_extract <- function(x, ...) {
   if (is_trained(x)) {
     if (length(x$levels) > 0) {
-      res <- purrr::map(x$levels, ~ tibble(columns = .x), FALSE)
+      res <- purrr::map(x$levels, ~tibble(columns = .x), FALSE)
       res <- purrr::list_rbind(res, names_to = "terms")
     } else {
       res <- tibble(terms = character(), columns = character())
@@ -319,3 +364,27 @@ tidy.step_dummy_extract <- function(x, ...) {
   res$id <- x$id
   res
 }
+
+#' @export
+.recipes_estimate_sparsity.step_dummy_extract <- function(x, data, ...) {
+  get_levels <- function(col) {
+    elements <- dummy_extract(
+      col[seq(1, min(10, length(col)))],
+      sep = x$sep,
+      pattern = x$pattern
+    )
+
+    lvls <- map(elements, unique)
+    lvls <- unlist(lvls)
+    length(lvls)
+  }
+
+  n_levels <- lapply(data, get_levels)
+
+  lapply(n_levels, function(n_lvl) {
+    c(
+      n_cols = n_lvl,
+      sparsity = 1 - 1 / n_lvl
+    )
+  })
+}
