@@ -3,6 +3,7 @@
 #' `step_geodist()` creates a *specification* of a recipe step that will
 #' calculate the distance between points on a map to a reference location.
 #'
+#' @inheritParams step_classdist
 #' @inheritParams step_pca
 #' @inheritParams step_center
 #' @param lon,lat Selector functions to choose which variables are
@@ -28,9 +29,19 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#' echoing the values of `lat`, `lon`, `ref_lat`, `ref_lon`,
-#' `is_lat_lon`, `name`, and `id` is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `latitude`, `longitude`, `ref_latitude`, `ref_longitude`,
+#' `is_lat_lon`, `name` , and `id`:
+#'
+#' \describe{
+#'   \item{latitude}{character, name of latitude variable}
+#'   \item{longitude}{character, name of longitude variable}
+#'   \item{ref_latitude}{numeric, location of latitude reference point}
+#'   \item{ref_longitude}{numeric, location of longitude reference point}
+#'   \item{is_lat_lon}{character, the summary function name}
+#'   \item{name}{character, name of resulting variable}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -51,43 +62,32 @@
 #'   arrange(geo_dist)
 #'
 #' tidy(near_station, number = 1)
-step_geodist <- function(recipe,
-                         lat = NULL,
-                         lon = NULL,
-                         role = "predictor",
-                         trained = FALSE,
-                         ref_lat = NULL,
-                         ref_lon = NULL,
-                         is_lat_lon = TRUE,
-                         log = FALSE,
-                         name = "geo_dist",
-                         columns = NULL,
-                         keep_original_cols = TRUE,
-                         skip = FALSE,
-                         id = rand_id("geodist")) {
-  if (length(ref_lon) != 1 || !is.numeric(ref_lon)) {
-    rlang::abort("`ref_lon` should be a single numeric value.")
+step_geodist <- function(
+  recipe,
+  lat = NULL,
+  lon = NULL,
+  role = "predictor",
+  trained = FALSE,
+  ref_lat = NULL,
+  ref_lon = NULL,
+  is_lat_lon = TRUE,
+  log = FALSE,
+  name = "geo_dist",
+  columns = NULL,
+  keep_original_cols = TRUE,
+  skip = FALSE,
+  id = rand_id("geodist")
+) {
+  check_bool(is_lat_lon)
+  if (is_lat_lon) {
+    check_number_decimal(ref_lat, min = -90, max = 90)
+    check_number_decimal(ref_lon, min = -180, max = 180)
+  } else {
+    check_number_decimal(ref_lat)
+    check_number_decimal(ref_lon)
   }
-  if (length(ref_lat) != 1 || !is.numeric(ref_lat)) {
-    rlang::abort("`ref_lat` should be a single numeric value.")
-  }
-  if (length(is_lat_lon) != 1 || !is.logical(is_lat_lon)) {
-    rlang::abort("`is_lat_lon` should be a single logical value.")
-  }
-  if (length(log) != 1 || !is.logical(log)) {
-    rlang::abort("`log` should be a single logical value.")
-  }
-  if (length(name) != 1 || !is.character(name)) {
-    rlang::abort("`name` should be a single character value.")
-  }
-
-  if (is_lat_lon && abs(ref_lat) > 90.0) {
-    rlang::abort("`ref_lat` should be between -90 and 90")
-  }
-  if (is_lat_lon && abs(ref_lon) > 180.0) {
-    rlang::abort("`ref_lon` should be between -180 and 180")
-  }
-
+  check_bool(log)
+  check_string(name)
 
   add_step(
     recipe,
@@ -110,8 +110,21 @@ step_geodist <- function(recipe,
 }
 
 step_geodist_new <-
-  function(lon, lat, role, trained, ref_lon, ref_lat, is_lat_lon,
-           log, name, columns, keep_original_cols, skip, id) {
+  function(
+    lon,
+    lat,
+    role,
+    trained,
+    ref_lon,
+    ref_lat,
+    is_lat_lon,
+    log,
+    name,
+    columns,
+    keep_original_cols,
+    skip,
+    id
+  ) {
     step(
       subclass = "geodist",
       lon = lon,
@@ -138,7 +151,6 @@ check_is_lat_lon <- function(x) {
   x
 }
 
-
 #' @export
 prep.step_geodist <- function(x, training, info = NULL, ...) {
   lon_name <- recipes_eval_select(x$lon, training, info)
@@ -148,12 +160,24 @@ prep.step_geodist <- function(x, training, info = NULL, ...) {
   x <- check_is_lat_lon(x)
 
   if (length(lon_name) > 1) {
-    rlang::abort("`lon` should resolve to a single column name.")
+    cli::cli_abort(
+      c(
+        x = "The {.arg lon} selector should select at most a single variable.",
+        i = "The following {length(lon_name)} were selected: \\
+          {.and {.var {lon_name}}}."
+      )
+    )
   }
   check_type(training[, lon_name], types = c("double", "integer"))
 
   if (length(lat_name) > 1) {
-    rlang::abort("`lat` should resolve to a single column name.")
+    cli::cli_abort(
+      c(
+        x = "The {.arg lat} selector should select at most a single variable.",
+        i = "The following {length(lat_name)} were selected: \\
+          {.and {.var {lat_name}}}."
+      )
+    )
   }
   check_type(training[, lat_name], types = c("double", "integer"))
 
@@ -179,16 +203,27 @@ geo_dist_calc_xy <- function(x_1, y_1, x_2, y_2) {
   sqrt((x_1 - x_2)^2L + (y_1 - y_2)^2L)
 }
 
-
 # earth_radius = 6371e3 in meters
-geo_dist_calc_lat_lon <- function(x_1, y_1, x_2, y_2, earth_radius = 6371e3,
-                                  call = caller_env()) {
+geo_dist_calc_lat_lon <- function(
+  x_1,
+  y_1,
+  x_2,
+  y_2,
+  earth_radius = 6371e3,
+  call = caller_env()
+) {
   if (any(abs(x_1) > 180.0)) {
-    rlang::abort("All `lon` values should be between -180 and 180", call = call)
+    cli::cli_abort(
+      "All {.var lon} values should be between -180 and 180.",
+      call = call
+    )
   }
 
   if (any(abs(y_1) > 90.0)) {
-    rlang::abort("All `lat` values should be between -90 and 90", call = call)
+    cli::cli_abort(
+      "All {.var lat} values should be between -90 and 90.",
+      call = call
+    )
   }
 
   to_rad <- pi / 180.0
@@ -208,7 +243,6 @@ geo_dist_calc_lat_lon <- function(x_1, y_1, x_2, y_2, earth_radius = 6371e3,
   earth_radius * c
 }
 
-
 #' @export
 bake.step_geodist <- function(object, new_data, ...) {
   col_names <- names(object$columns)
@@ -247,24 +281,25 @@ bake.step_geodist <- function(object, new_data, ...) {
 
   geo_data <- check_name(geo_data, new_data, object, newname = object$name)
 
-  new_data <- vec_cbind(new_data, geo_data)
+  new_data <- vec_cbind(new_data, geo_data, .name_repair = "minimal")
   new_data <- remove_original_cols(new_data, object, col_names)
   new_data
 }
 
+#' @export
 print.step_geodist <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- paste(
       "Geographical distances from",
-      format(x$ref_lat, digits = 10), "x",
-      format(x$ref_lon, digits = 10), "using "
+      format(x$ref_lat, digits = 10),
+      "x",
+      format(x$ref_lon, digits = 10),
+      "using "
     )
     print_step(x$columns, c(x$lat, x$lon), x$trained, title, width)
     invisible(x)
   }
 
-
-
 #' @rdname tidy.recipe
 #' @export
 tidy.step_geodist <- function(x, ...) {
