@@ -88,19 +88,21 @@
 #' tidy(ica_trans, number = 3)
 #' tidy(ica_estimates, number = 3)
 step_ica <-
-  function(recipe,
-           ...,
-           role = "predictor",
-           trained = FALSE,
-           num_comp = 5,
-           options = list(method = "C"),
-           seed = sample.int(10000, 5),
-           res = NULL,
-           columns = NULL,
-           prefix = "IC",
-           keep_original_cols = FALSE,
-           skip = FALSE,
-           id = rand_id("ica")) {
+  function(
+    recipe,
+    ...,
+    role = "predictor",
+    trained = FALSE,
+    num_comp = 5,
+    options = list(method = "C"),
+    seed = sample.int(10000, 5),
+    res = NULL,
+    columns = NULL,
+    prefix = "IC",
+    keep_original_cols = FALSE,
+    skip = FALSE,
+    id = rand_id("ica")
+  ) {
     recipes_pkg_check(required_pkgs.step_ica())
 
     add_step(
@@ -123,8 +125,20 @@ step_ica <-
   }
 
 step_ica_new <-
-  function(terms, role, trained, num_comp, options, seed, res, columns,
-           prefix, keep_original_cols, skip, id) {
+  function(
+    terms,
+    role,
+    trained,
+    num_comp,
+    options,
+    seed,
+    res,
+    columns,
+    prefix,
+    keep_original_cols,
+    skip,
+    id
+  ) {
     step(
       subclass = "ica",
       terms = terms,
@@ -162,10 +176,12 @@ prep.step_ica <- function(x, training, info = NULL, ...) {
     indc <- try(withr::with_seed(x$seed, rlang::eval_tidy(cl)), silent = TRUE)
 
     if (inherits(indc, "try-error")) {
-      cli::cli_abort(c(
-        x = "Failed with error:",
-        i = as.character(indc)
-      ))
+      cli::cli_abort(
+        c(
+          x = "Failed with error:",
+          i = as.character(indc)
+        )
+      )
     }
 
     indc <- indc[c("K", "W")]
@@ -201,16 +217,17 @@ bake.step_ica <- function(object, new_data, ...) {
     return(new_data)
   }
 
-
-  comps <- scale(as.matrix(new_data[, col_names]),
-    center = object$res$means, scale = FALSE
+  comps <- scale(
+    as.matrix(new_data[, col_names]),
+    center = object$res$means,
+    scale = FALSE
   )
   comps <- comps %*% object$res$K %*% object$res$W
   comps <- comps[, seq_len(object$num_comp), drop = FALSE]
   colnames(comps) <- names0(ncol(comps), object$prefix)
   comps <- as_tibble(comps)
   comps <- check_name(comps, new_data, object)
-  new_data <- vec_cbind(new_data, comps)
+  new_data <- vec_cbind(new_data, comps, .name_repair = "minimal")
 
   new_data <- remove_original_cols(new_data, object, col_names)
   new_data
@@ -284,7 +301,6 @@ tunable.step_ica <- function(x, ...) {
   )
 }
 
-
 #' @rdname required_pkgs.recipe
 #' @export
 required_pkgs.step_ica <- function(x, ...) {
