@@ -23,9 +23,14 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#' `terms` (the selectors or variables selected) and `model` (the mode
-#' value) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `value` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{value}{character, the mode value}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-unsupervised
 #'
@@ -49,21 +54,23 @@
 #'
 #' imp_models <- prep(impute_rec, training = credit_tr)
 #'
-#' imputed_te <- bake(imp_models, new_data = credit_te, everything())
+#' imputed_te <- bake(imp_models, new_data = credit_te)
 #'
 #' table(credit_te$Home, imputed_te$Home, useNA = "always")
 #'
 #' tidy(impute_rec, number = 1)
 #' tidy(imp_models, number = 1)
 step_impute_mode <-
-  function(recipe,
-           ...,
-           role = NA,
-           trained = FALSE,
-           modes = NULL,
-           ptype = NULL,
-           skip = FALSE,
-           id = rand_id("impute_mode")) {
+  function(
+    recipe,
+    ...,
+    role = NA,
+    trained = FALSE,
+    modes = NULL,
+    ptype = NULL,
+    skip = FALSE,
+    id = rand_id("impute_mode")
+  ) {
     add_step(
       recipe,
       step_impute_mode_new(
@@ -79,34 +86,6 @@ step_impute_mode <-
     )
   }
 
-#' @rdname step_impute_mode
-#' @export
-step_modeimpute <-
-  function(recipe,
-           ...,
-           role = NA,
-           trained = FALSE,
-           modes = NULL,
-           ptype = NULL,
-           skip = FALSE,
-           id = rand_id("impute_mode")) {
-    lifecycle::deprecate_stop(
-      when = "0.1.16",
-      what = "recipes::step_modeimpute()",
-      with = "recipes::step_impute_mode()"
-    )
-    step_impute_mode(
-      recipe,
-      ...,
-      role = role,
-      trained = trained,
-      modes = modes,
-      ptype = ptype,
-      skip = skip,
-      id = id
-    )
-  }
-
 step_impute_mode_new <-
   function(terms, role, trained, modes, ptype, skip, id, case_weights) {
     step(
@@ -146,24 +125,21 @@ prep.step_impute_mode <- function(x, training, info = NULL, ...) {
   )
 }
 
-#' @export
-#' @keywords internal
-prep.step_modeimpute <- prep.step_impute_mode
-
 #' @export
 bake.step_impute_mode <- function(object, new_data, ...) {
   col_names <- names(object$modes)
   check_new_data(col_names, object, new_data)
 
   for (col_name in col_names) {
-    if (!any(is.na(new_data[[col_name]]))) {
+    if (!anyNA(new_data[[col_name]])) {
       next
     }
     if (is.null(object$ptype)) {
-      rlang::warn(
-        paste0(
-          "'ptype' was added to `step_impute_mode()` after this recipe was created.\n",
-          "Regenerate your recipe to avoid this warning."
+      cli::cli_warn(
+        c(
+          "!" = "{.arg ptype} was added to {.fn step_impute_mode} after this \\
+              recipe was created.",
+          "i" = "Regenerate your recipe to avoid this warning."
         )
       )
     } else {
@@ -179,27 +155,26 @@ bake.step_impute_mode <- function(object, new_data, ...) {
   new_data
 }
 
-#' @export
-#' @keywords internal
-bake.step_modeimpute <- bake.step_impute_mode
-
 #' @export
 print.step_impute_mode <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Mode imputation for "
-    print_step(names(x$modes), x$terms, x$trained, title, width,
-               case_weights = x$case_weights)
+    print_step(
+      names(x$modes),
+      x$terms,
+      x$trained,
+      title,
+      width,
+      case_weights = x$case_weights
+    )
     invisible(x)
   }
 
-#' @export
-#' @keywords internal
-print.step_modeimpute <- print.step_impute_mode
-
 mode_est <- function(x, wts = NULL, call = caller_env(2)) {
   if (!is.character(x) & !is.factor(x))
-    rlang::abort(
-      "The data should be character or factor to compute the mode.",
+    cli::cli_abort(
+      "The data should be character or factor to compute the mode. \\
+      Not {.obj_type_friendly {x}}.",
       call = call
     )
   tab <- weighted_table(x, wts = wts)
@@ -222,7 +197,3 @@ tidy.step_impute_mode <- function(x, ...) {
   res$id <- x$id
   res
 }
-
-#' @export
-#' @keywords internal
-tidy.step_modeimpute <- tidy.step_impute_mode
