@@ -87,15 +87,17 @@
 #' tidy(int_mod_1, number = 1)
 #' tidy(int_mod_2, number = 2)
 step_interact <-
-  function(recipe,
-           terms,
-           role = "predictor",
-           trained = FALSE,
-           objects = NULL,
-           sep = "_x_",
-           keep_original_cols = TRUE,
-           skip = FALSE,
-           id = rand_id("interact")) {
+  function(
+    recipe,
+    terms,
+    role = "predictor",
+    trained = FALSE,
+    objects = NULL,
+    sep = "_x_",
+    keep_original_cols = TRUE,
+    skip = FALSE,
+    id = rand_id("interact")
+  ) {
     add_step(
       recipe,
       step_interact_new(
@@ -128,16 +130,14 @@ step_interact_new <-
     )
   }
 
-
 ## The idea is to save a bunch of x-factor interaction terms instead of
 ## one large set of collected terms.
 #' @export
 prep.step_interact <- function(x, training, info = NULL, ...) {
-
   # Empty selection
   if (identical(x$terms[[1]], quo())) {
     return(
-        step_interact_new(
+      step_interact_new(
         terms = x$terms,
         role = x$role,
         trained = TRUE,
@@ -242,16 +242,16 @@ prep.step_interact <- function(x, training, info = NULL, ...) {
   )
 }
 
-
 #' @export
 bake.step_interact <- function(object, new_data, ...) {
-
   # empty selection
   if (is.null(object$objects)) {
     return(new_data)
   }
 
-  col_names <- unlist(lapply(object$objects, function(x) all.vars(rlang::f_rhs(x))))
+  col_names <- unlist(
+    lapply(object$objects, function(x) all.vars(rlang::f_rhs(x)))
+  )
   check_new_data(col_names, object, new_data)
 
   # When the interaction specification failed, just move on
@@ -287,7 +287,7 @@ bake.step_interact <- function(object, new_data, ...) {
     gsub(":", object$sep, unlist(lapply(res, colnames)))
   out <- as_tibble(out)
   out <- check_name(out, new_data, object, names(out))
-  new_data <- vec_cbind(new_data, out)
+  new_data <- vec_cbind(new_data, out, .name_repair = "minimal")
   new_data <- remove_original_cols(new_data, object, col_names)
   new_data
 }
@@ -309,8 +309,6 @@ make_new_formula <- function(x) {
   lapply(splitup, x_fac_int)
 }
 
-
-
 ## Given a standard model formula and some data, get the
 ## term expansion (without `.`s). This returns the factor
 ## names and would not expand dummy variables.
@@ -331,11 +329,13 @@ get_term_names <- function(form, vnames) {
   )
   if (inherits(nms, "try-error")) {
     # have not been able to reach
-    cli::cli_warn(c(
-      "!" = "Interaction specification failed for:",
-      "*" = deparse(form),
-      "i" = "No interactions will be created"
-    ))
+    cli::cli_warn(
+      c(
+        "!" = "Interaction specification failed for:",
+        "*" = deparse(form),
+        "i" = "No interactions will be created"
+      )
+    )
     return(rlang::na_chr)
   }
   nms <- nms[nms != "(Intercept)"]
@@ -378,7 +378,6 @@ int_name <- function(x) {
   res
 }
 
-
 #' @rdname tidy.recipe
 #' @export
 tidy.step_interact <- function(x, ...) {
@@ -390,7 +389,6 @@ tidy.step_interact <- function(x, ...) {
 map_call <- function(x, f, ...) as.call(lapply(x, f, ...))
 map_pairlist <- function(x, f, ...) as.pairlist(lapply(x, f, ...))
 
-
 # In a formula, find the selectors (if any) and return the call(s)
 find_selectors <- function(f) {
   if (is.function(f)) {
