@@ -1,4 +1,4 @@
-#' Inverse Logit Transformation
+#' Inverse logit transformation
 #'
 #' `step_invlogit()` creates a *specification* of a recipe step that will
 #' transform the data from real values to be between zero and one.
@@ -12,10 +12,15 @@
 #'  real line and translates them to be between zero and one using
 #'  the function `f(x) = 1/(1+exp(-x))`.
 #'
-#'  # Tidying
+#' # Tidying
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#'  `terms` (the columns that will be affected) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -40,8 +45,15 @@
 #' transformed_te <- bake(ilogit_obj, biomass_te)
 #' plot(biomass_te$carbon, transformed_te$carbon)
 step_invlogit <-
-  function(recipe, ..., role = NA, trained = FALSE, columns = NULL,
-           skip = FALSE, id = rand_id("invlogit")) {
+  function(
+    recipe,
+    ...,
+    role = NA,
+    trained = FALSE,
+    columns = NULL,
+    skip = FALSE,
+    id = rand_id("invlogit")
+  ) {
     add_step(
       recipe,
       step_invlogit_new(
@@ -95,7 +107,7 @@ bake.step_invlogit <- function(object, new_data, ...) {
   new_data
 }
 
-
+#' @export
 print.step_invlogit <-
   function(x, width = max(20, options()$width - 26), ...) {
     title <- "Inverse logit on "
