@@ -1,4 +1,4 @@
-#' Check for Missing Values
+#' Check for missing values
 #'
 #' `check_missing` creates a *specification* of a recipe
 #'  operation that will check if variables contain missing values.
@@ -62,13 +62,15 @@
 #' bake(rp, test_data)
 #' }
 check_missing <-
-  function(recipe,
-           ...,
-           role = NA,
-           trained = FALSE,
-           columns = NULL,
-           skip = FALSE,
-           id = rand_id("missing")) {
+  function(
+    recipe,
+    ...,
+    role = NA,
+    trained = FALSE,
+    columns = NULL,
+    skip = FALSE,
+    id = rand_id("missing")
+  ) {
     add_check(
       recipe,
       check_missing_new(
@@ -119,15 +121,14 @@ bake.check_missing <- function(object, new_data, ...) {
   nr_na <- colSums(is.na(subset_to_check))
   if (any(nr_na > 0)) {
     with_na <- names(nr_na[nr_na > 0])
-    with_na_str <- paste(paste0("`", with_na, "`"), collapse = ", ")
-    rlang::abort(paste0(
-      "The following columns contain missing values: ",
-      with_na_str, "."
-    ))
+    cli::cli_abort(
+      "The following columns contains missing values: {with_na}."
+    )
   }
   new_data
 }
 
+#' @export
 print.check_missing <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Check missing values for "
