@@ -10,6 +10,20 @@
 #' @param trained A logical to indicate if the quantities for preprocessing
 #'   have been estimated. Again included for consistency.
 #'
+#' @details
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
+#'
+#' @template sparse-preserve
+#'
 #' @template case-weights-not-supported
 #'
 #' @template step-return
@@ -22,9 +36,15 @@
 #'   step_naomit(Solar.R) %>%
 #'   prep(airquality, verbose = FALSE) %>%
 #'   bake(new_data = NULL)
-step_naomit <- function(recipe, ..., role = NA, trained = FALSE,
-                        columns = NULL, skip = TRUE,
-                        id = rand_id("naomit")) {
+step_naomit <- function(
+  recipe,
+  ...,
+  role = NA,
+  trained = FALSE,
+  columns = NULL,
+  skip = TRUE,
+  id = rand_id("naomit")
+) {
   add_step(
     recipe,
     step_naomit_new(
@@ -70,6 +90,7 @@ bake.step_naomit <- function(object, new_data, ...) {
   tibble::as_tibble(tidyr::drop_na(new_data, tidyselect::all_of(col_names)))
 }
 
+#' @export
 print.step_naomit <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Removing rows with NA values in "
@@ -84,3 +105,8 @@ tidy.step_naomit <- function(x, ...) {
   res$id <- x$id
   res
 }
+
+#' @export
+.recipes_preserve_sparsity.step_naomit <- function(x, ...) {
+  TRUE
+}
