@@ -69,14 +69,16 @@
 #'
 #' tidy(nonlin_scores, number = 2)
 step_ordinalscore <-
-  function(recipe,
-           ...,
-           role = NA,
-           trained = FALSE,
-           columns = NULL,
-           convert = as.numeric,
-           skip = FALSE,
-           id = rand_id("ordinalscore")) {
+  function(
+    recipe,
+    ...,
+    role = NA,
+    trained = FALSE,
+    columns = NULL,
+    convert = as.numeric,
+    skip = FALSE,
+    id = rand_id("ordinalscore")
+  ) {
     add_step(
       recipe,
       step_ordinalscore_new(
@@ -107,20 +109,20 @@ step_ordinalscore_new <-
 
 #' @export
 prep.step_ordinalscore <- function(x, training, info = NULL, ...) {
-    col_names <- recipes_eval_select(x$terms, training, info)
-    check_type(training[, col_names], types = "ordered")
-    check_function(x$convert, arg = "convert")
+  col_names <- recipes_eval_select(x$terms, training, info)
+  check_type(training[, col_names], types = "ordered")
+  check_function(x$convert, arg = "convert")
 
-    step_ordinalscore_new(
-      terms = x$terms,
-      role = x$role,
-      trained = TRUE,
-      columns = col_names,
-      convert = x$convert,
-      skip = x$skip,
-      id = x$id
-    )
-  }
+  step_ordinalscore_new(
+    terms = x$terms,
+    role = x$role,
+    trained = TRUE,
+    columns = col_names,
+    convert = x$convert,
+    skip = x$skip,
+    id = x$id
+  )
+}
 
 #' @export
 bake.step_ordinalscore <- function(object, new_data, ...) {
@@ -144,7 +146,6 @@ print.step_ordinalscore <-
     invisible(x)
   }
 
-
 #' @rdname tidy.recipe
 #' @export
 tidy.step_ordinalscore <- function(x, ...) {
