@@ -1,4 +1,4 @@
-#' Check Range Consistency
+#' Check range consistency
 #'
 #' `check_range` creates a *specification* of a recipe
 #'  check that will check if the range of a numeric
@@ -58,16 +58,18 @@
 #'   bake(slack_new_data)
 #' }
 check_range <-
-  function(recipe,
-           ...,
-           role = NA,
-           skip = FALSE,
-           trained = FALSE,
-           slack_prop = 0.05,
-           warn = FALSE,
-           lower = NULL,
-           upper = NULL,
-           id = rand_id("range_check_")) {
+  function(
+    recipe,
+    ...,
+    role = NA,
+    skip = FALSE,
+    trained = FALSE,
+    slack_prop = 0.05,
+    warn = FALSE,
+    lower = NULL,
+    upper = NULL,
+    id = rand_id("range_check_")
+  ) {
     add_check(
       recipe,
       check_range_new(
@@ -102,46 +104,50 @@ check_range_new <-
   }
 
 #' @export
-prep.check_range <- function(x,
-                             training,
-                             info = NULL,
-                             ...) {
+prep.check_range <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
 
   ## TODO add informative error for nonnumerics
 
-  lower_vals <- vapply(training[, col_names], min, c(min = 1),
-    na.rm = TRUE
-  )
-  upper_vals <- vapply(training[, col_names], max, c(max = 1),
-    na.rm = TRUE
-  )
+  lower_vals <- vapply(training[, col_names], min, c(min = 1), na.rm = TRUE)
+  upper_vals <- vapply(training[, col_names], max, c(max = 1), na.rm = TRUE)
   check_range_new(
-    terms      = x$terms,
-    role       = x$role,
-    trained    = TRUE,
-    skip       = x$skip,
-    warn       = x$warn,
-    lower      = lower_vals,
-    upper      = upper_vals,
+    terms = x$terms,
+    role = x$role,
+    trained = TRUE,
+    skip = x$skip,
+    warn = x$warn,
+    lower = lower_vals,
+    upper = upper_vals,
     slack_prop = x$slack_prop,
-    id         = x$id
+    id = x$id
   )
 }
 
-range_check_func <- function(x,
-                             lower,
-                             upper,
-                             slack_prop = 0.05,
-                             warn = FALSE,
-                             colname = "x") {
-  stopifnot(
-    is.numeric(slack_prop),
-    is.numeric(x)
-  )
+range_check_func <- function(
+  x,
+  lower,
+  upper,
+  slack_prop = 0.05,
+  warn = FALSE,
+  colname = "x"
+) {
+  if (!is.numeric(x)) {
+    cli::cli_abort(
+      "{.arg x} must be a numeric vector, not {.obj_type_friendly {x}}."
+    )
+  }
+
+  if (!is.numeric(slack_prop)) {
+    cli::cli_abort(
+      "{.arg slack_prop} must be a numeric vector, \\
+      not {.obj_type_friendly {slack_prop}}."
+    )
+  }
+
   min_x <- min(x)
   max_x <- max(x)
-  msg <- NULL
+
   if (length(slack_prop) == 1) {
     lower_allowed <- lower - ((upper - lower) * slack_prop)
     upper_allowed <- upper + ((upper - lower) * slack_prop)
@@ -149,30 +155,33 @@ range_check_func <- function(x,
     lower_allowed <- lower - ((upper - lower) * slack_prop[1])
     upper_allowed <- upper + ((upper - lower) * slack_prop[2])
   } else {
-    rlang::abort("slack_prop should be of length 1 or of length 2")
+    cli::cli_abort(
+      "{.arg slack_prop} should be of length 1 or 2, not {length(slack_prop)}."
+    )
   }
 
-  if (min_x < lower_allowed & max_x > upper_allowed) {
-    msg <- paste0(
-      "min ", colname, " is ", min_x, ", lower bound is ",
-      lower_allowed, ", max x is ", max_x, ", upper bound is ",
-      upper_allowed
-    )
-  } else if (min_x < lower_allowed) {
-    msg <- paste0(
-      "min ", colname, " is ", min_x, ", lower bound is ",
-      lower_allowed
-    )
-  } else if (max_x > upper_allowed) {
-    msg <- paste0(
-      "max ", colname, " is ", max_x, ", upper bound is ",
-      upper_allowed
+  msg <- NULL
+  if (min_x < lower_allowed) {
+    msg <- c(
+      msg,
+      i = "Smallest value of {.var {colname}} is {min_x}, \\
+      crossing the lower bound {lower_allowed}."
     )
   }
-  if (warn & !is.null(msg)) {
-    rlang::warn(msg)
-  } else if (!is.null(msg)) {
-    rlang::abort(msg)
+  if (max_x > upper_allowed) {
+    msg <- c(
+      msg,
+      i = "Largest value of {.var {colname}} is {max_x}, \\
+      crossing the upper bound {upper_allowed}."
+    )
+  }
+
+  if (!is.null(msg)) {
+    if (warn) {
+      cli::cli_warn(msg)
+    } else {
+      cli::cli_abort(msg)
+    }
   }
 }
 
@@ -194,6 +203,7 @@ bake.check_range <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.check_range <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Checking range of "
@@ -201,7 +211,6 @@ print.check_range <-
     invisible(x)
   }
 
-
 #' @rdname tidy.recipe
 #' @export
 tidy.check_range <- function(x, ...) {
