@@ -6,6 +6,7 @@
 #' @inheritParams step_classdist
 #' @inheritParams step_pca
 #' @inheritParams step_center
+#' @inheritParams step_dummy
 #' @param ... A single selector function to choose which variable
 #'  will be searched for the regex pattern. The selector should resolve
 #'  to a single variable. See [selections()] for more details.
@@ -34,6 +35,8 @@
 #'   \item{id}{character, id of this step}
 #' }
 #'
+#' @template sparse-creation
+#'
 #' @template case-weights-not-supported
 #'
 #' @family dummy variable and encoding steps
@@ -52,34 +55,40 @@
 #' with_dummies
 #' tidy(rec, number = 1)
 #' tidy(rec2, number = 1)
-step_regex <- function(recipe,
-                       ...,
-                       role = "predictor",
-                       trained = FALSE,
-                       pattern = ".",
-                       options = list(),
-                       result = make.names(pattern),
-                       input = NULL,
-                       keep_original_cols = TRUE,
-                       skip = FALSE,
-                       id = rand_id("regex")) {
-
+step_regex <- function(
+  recipe,
+  ...,
+  role = "predictor",
+  trained = FALSE,
+  pattern = ".",
+  options = list(),
+  result = make.names(pattern),
+  input = NULL,
+  sparse = "auto",
+  keep_original_cols = TRUE,
+  skip = FALSE,
+  id = rand_id("regex")
+) {
   valid_args <- names(formals(grepl))[-(1:2)]
   if (any(!(names(options) %in% valid_args))) {
-    cli::cli_abort(c(
-      "x" = "The following elements of {.arg options} are not allowed:",
-      "*" = "{.val {setdiff(names(options), valid_args)}}.",
-      "i" = "Valid options are: {.val {valid_args}}."
-    ))
+    cli::cli_abort(
+      c(
+        "x" = "The following elements of {.arg options} are not allowed:",
+        "*" = "{.val {setdiff(names(options), valid_args)}}.",
+        "i" = "Valid options are: {.val {valid_args}}."
+      )
+    )
   }
 
   terms <- enquos(...)
   if (length(terms) > 1) {
-    cli::cli_abort(c(
-      x = "For this step, only a single selector can be used.",
-      i = "The following {length(terms)} selectors were used: \\
+    cli::cli_abort(
+      c(
+        x = "For this step, only a single selector can be used.",
+        i = "The following {length(terms)} selectors were used: \\
           {.var {as.character(terms)}}."
-    ))
+      )
+    )
   }
 
   add_step(
@@ -92,6 +101,7 @@ step_regex <- function(recipe,
       options = options,
       result = result,
       input = input,
+      sparse = sparse,
       keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
@@ -100,8 +110,19 @@ step_regex <- function(recipe,
 }
 
 step_regex_new <-
-  function(terms, role, trained, pattern, options, result, input,
-           keep_original_cols, skip, id) {
+  function(
+    terms,
+    role,
+    trained,
+    pattern,
+    options,
+    result,
+    input,
+    sparse,
+    keep_original_cols,
+    skip,
+    id
+  ) {
     step(
       subclass = "regex",
       terms = terms,
@@ -111,6 +132,7 @@ step_regex_new <-
       options = options,
       result = result,
       input = input,
+      sparse = sparse,
       keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
@@ -122,6 +144,7 @@ prep.step_regex <- function(x, training, info = NULL, ...) {
   col_name <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_name], types = c("string", "factor", "ordered"))
   check_string(x$pattern, arg = "pattern", allow_empty = FALSE)
+  check_sparse_arg(x$sparse)
 
   step_regex_new(
     terms = x$terms,
@@ -131,6 +154,7 @@ prep.step_regex <- function(x, training, info = NULL, ...) {
     options = x$options,
     input = col_name,
     result = x$result,
+    sparse = x$sparse,
     keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
@@ -162,8 +186,15 @@ bake.step_regex <- function(object, new_data, ...) {
   }
 
   new_values <- tibble::tibble(!!object$result := ifelse(eval(regex), 1L, 0L))
+
+  if (sparse_is_yes(object$sparse)) {
+    new_values[[object$result]] <- sparsevctrs::as_sparse_integer(
+      new_values[[object$result]]
+    )
+  }
+
   new_values <- check_name(new_values, new_data, object, object$result)
-  new_data <- vec_cbind(new_data, new_values)
+  new_data <- vec_cbind(new_data, new_values, .name_repair = "minimal")
   new_data <- remove_original_cols(new_data, object, col_name)
   new_data
 }
@@ -178,7 +209,6 @@ print.step_regex <-
     invisible(x)
   }
 
-
 #' @rdname tidy.recipe
 #' @export
 tidy.step_regex <- function(x, ...) {
@@ -198,3 +228,13 @@ tidy.step_regex <- function(x, ...) {
   res$id <- x$id
   res
 }
+
+#' @export
+.recipes_estimate_sparsity.step_regex <- function(x, data, ...) {
+  lapply(1, function(n_lvl) {
+    c(
+      n_cols = n_lvl,
+      sparsity = 0.5
+    )
+  })
+}
