@@ -8,13 +8,22 @@ examples <- data.frame(
 
 examples$Dan <- as.POSIXct(examples$Dan)
 
-date_rec <- recipe(~ Dan + Stefan, examples) %>%
+date_rec <- recipe(~Dan + Stefan, examples) %>%
   step_date(all_predictors())
 
-feats <- c("year", "doy", "week", "decimal", "semester", "quarter", "dow", "month")
+feats <- c(
+  "year",
+  "doy",
+  "week",
+  "decimal",
+  "semester",
+  "quarter",
+  "dow",
+  "month"
+)
 
 test_that("default option", {
-  date_rec <- recipe(~ Dan + Stefan, examples) %>%
+  date_rec <- recipe(~Dan + Stefan, examples) %>%
     step_date(all_predictors(), features = feats)
 
   date_rec <- prep(date_rec, training = examples)
@@ -40,18 +49,33 @@ test_that("default option", {
     Stefan_dow = wday(examples$Stefan, label = TRUE, abbr = TRUE),
     Stefan_month = month(examples$Stefan, label = TRUE, abbr = TRUE)
   )
-  date_exp$Dan_dow <- factor(as.character(date_exp$Dan_dow), levels = levels(date_exp$Dan_dow))
-  date_exp$Dan_month <- factor(as.character(date_exp$Dan_month), levels = levels(date_exp$Dan_month))
-  date_exp$Stefan_dow <- factor(as.character(date_exp$Stefan_dow), levels = levels(date_exp$Stefan_dow))
-  date_exp$Stefan_month <- factor(as.character(date_exp$Stefan_month), levels = levels(date_exp$Stefan_month))
+  date_exp$Dan_dow <- factor(
+    as.character(date_exp$Dan_dow),
+    levels = levels(date_exp$Dan_dow)
+  )
+  date_exp$Dan_month <- factor(
+    as.character(date_exp$Dan_month),
+    levels = levels(date_exp$Dan_month)
+  )
+  date_exp$Stefan_dow <- factor(
+    as.character(date_exp$Stefan_dow),
+    levels = levels(date_exp$Stefan_dow)
+  )
+  date_exp$Stefan_month <- factor(
+    as.character(date_exp$Stefan_month),
+    levels = levels(date_exp$Stefan_month)
+  )
 
   expect_identical(date_res, date_exp)
 })
 
-
 test_that("nondefault options", {
-  date_rec <- recipe(~ Dan + Stefan, examples) %>%
-    step_date(all_predictors(), features = c("dow", "month", "mday"), label = FALSE)
+  date_rec <- recipe(~Dan + Stefan, examples) %>%
+    step_date(
+      all_predictors(),
+      features = c("dow", "month", "mday"),
+      label = FALSE
+    )
 
   date_rec <- prep(date_rec, training = examples)
   date_res <- bake(date_rec, new_data = examples)
@@ -70,9 +94,8 @@ test_that("nondefault options", {
   expect_equal(date_res, date_exp)
 })
 
-
 test_that("ordinal values", {
-  date_rec <- recipe(~ Dan + Stefan, examples) %>%
+  date_rec <- recipe(~Dan + Stefan, examples) %>%
     step_date(all_predictors(), features = c("dow", "month"), ordinal = TRUE)
 
   date_rec <- prep(date_rec, training = examples)
@@ -111,7 +134,7 @@ test_that("locale argument have recipe work in different locale", {
   withr::defer(Sys.setlocale("LC_TIME", old_locale))
   Sys.setlocale("LC_TIME", 'fr_FR.UTF8')
 
-  date_rec <- recipe(~ Dan + Stefan, examples) %>%
+  date_rec <- recipe(~Dan + Stefan, examples) %>%
     step_date(all_predictors()) %>%
     prep()
 
@@ -130,7 +153,7 @@ test_that("locale argument works when specified", {
 
   old_locale <- Sys.getlocale("LC_TIME")
   withr::defer(Sys.setlocale("LC_TIME", old_locale))
-  date_rec <- recipe(~ Dan + Stefan, examples) %>%
+  date_rec <- recipe(~Dan + Stefan, examples) %>%
     step_date(all_predictors()) %>%
     prep()
 
@@ -138,7 +161,7 @@ test_that("locale argument works when specified", {
 
   Sys.setlocale("LC_TIME", 'fr_FR.UTF-8')
 
-  date_rec <- recipe(~ Dan + Stefan, examples) %>%
+  date_rec <- recipe(~Dan + Stefan, examples) %>%
     step_date(all_predictors(), locale = old_locale) %>%
     prep()
 
@@ -150,7 +173,7 @@ test_that("locale argument works when specified", {
 test_that("locale argument works with clock locale", {
   labels_fr <- clock::clock_locale(labels = "fr")$labels
 
-  date_rec <- recipe(~ Stefan, examples) %>%
+  date_rec <- recipe(~Stefan, examples) %>%
     step_date(all_predictors(), locale = labels_fr, ordinal = TRUE) %>%
     prep()
 
@@ -175,7 +198,7 @@ test_that("locale argument works with clock locale", {
 })
 
 test_that("can bake and recipes with no locale", {
-  date_rec <- recipe(~ Dan + Stefan, examples) %>%
+  date_rec <- recipe(~Dan + Stefan, examples) %>%
     step_date(all_predictors()) %>%
     prep()
 
@@ -189,19 +212,22 @@ test_that("can bake and recipes with no locale", {
 test_that("errors on wrong values of features", {
   expect_snapshot(
     error = TRUE,
-    recipe(~ Dan + Stefan, examples) %>%
+    recipe(~Dan + Stefan, examples) %>%
       step_date(all_predictors(), features = "yearly") %>%
       prep()
   )
   expect_snapshot(
     error = TRUE,
-    recipe(~ Dan + Stefan, examples) %>%
-      step_date(all_predictors(), features = c("daily", "monthly", "yearly")) %>%
+    recipe(~Dan + Stefan, examples) %>%
+      step_date(
+        all_predictors(),
+        features = c("daily", "monthly", "yearly")
+      ) %>%
       prep()
   )
   expect_snapshot(
     error = TRUE,
-    recipe(~ Dan + Stefan, examples) %>%
+    recipe(~Dan + Stefan, examples) %>%
       step_date(all_predictors(), features = c("daily", "month", "yearly")) %>%
       prep()
   )
@@ -210,7 +236,7 @@ test_that("errors on wrong values of features", {
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
-  date_rec <- recipe(~ Dan + Stefan, examples) %>%
+  date_rec <- recipe(~Dan + Stefan, examples) %>%
     step_date(Dan, features = feats) %>%
     update_role(Dan, new_role = "potato") %>%
     update_role_requirements(role = "potato", bake = FALSE)
@@ -218,7 +244,10 @@ test_that("bake method errors when needed non-standard role columns are missing"
   date_rec <- prep(date_rec, training = examples)
   date_res <- bake(date_rec, new_data = examples)
 
-  expect_snapshot(error = TRUE, bake(date_rec, new_data = examples[, 2, drop = FALSE]))
+  expect_snapshot(
+    error = TRUE,
+    bake(date_rec, new_data = examples[, 2, drop = FALSE])
+  )
 })
 
 test_that("empty printing", {
@@ -266,7 +295,7 @@ test_that("empty selection tidy method works", {
 test_that("keep_original_cols works", {
   new_names <- c("Dan_dow", "Dan_month", "Dan_year")
 
-  rec <- recipe(~ Dan, examples) %>%
+  rec <- recipe(~Dan, examples) %>%
     step_date(all_predictors(), keep_original_cols = FALSE)
 
   rec <- prep(rec)
@@ -277,7 +306,7 @@ test_that("keep_original_cols works", {
     new_names
   )
 
-  rec <- recipe(~ Dan, examples) %>%
+  rec <- recipe(~Dan, examples) %>%
     step_date(all_predictors(), keep_original_cols = TRUE)
 
   rec <- prep(rec)
@@ -290,7 +319,7 @@ test_that("keep_original_cols works", {
 })
 
 test_that("keep_original_cols - can prep recipes with it missing", {
-  rec <- recipe(~ Dan, examples) %>%
+  rec <- recipe(~Dan, examples) %>%
     step_date(all_predictors())
 
   rec$steps[[1]]$keep_original_cols <- NULL
@@ -305,7 +334,7 @@ test_that("keep_original_cols - can prep recipes with it missing", {
 })
 
 test_that("printing", {
-  rec <- recipe(~ Dan + Stefan, examples) %>%
+  rec <- recipe(~Dan + Stefan, examples) %>%
     step_date(all_predictors(), features = feats)
 
   expect_snapshot(print(rec))
@@ -313,24 +342,22 @@ test_that("printing", {
 })
 
 test_that("bad args", {
-
   expect_snapshot(
-    date_rec <- recipe(~ Dan + Stefan, examples) %>%
+    date_rec <- recipe(~Dan + Stefan, examples) %>%
       step_date(all_predictors(), abbr = "nope") %>%
       prep(),
     error = TRUE
   )
   expect_snapshot(
-    date_rec <- recipe(~ Dan + Stefan, examples) %>%
+    date_rec <- recipe(~Dan + Stefan, examples) %>%
       step_date(all_predictors(), label = "no!") %>%
       prep(),
     error = TRUE
   )
   expect_snapshot(
-    date_rec <- recipe(~ Dan + Stefan, examples) %>%
+    date_rec <- recipe(~Dan + Stefan, examples) %>%
       step_date(all_predictors(), ordinal = "never") %>%
       prep(),
     error = TRUE
   )
 })
-
