@@ -3,8 +3,8 @@ library(recipes)
 skip_if_not_installed("modeldata")
 data(biomass, package = "modeldata")
 
-
-rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
+rec <- recipe(
+  HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
   data = biomass
 )
 
@@ -23,7 +23,8 @@ test_that("imputation values", {
   discr_rec <- rec %>%
     step_discretize(nitrogen, options = list(keep_na = FALSE))
   impute_rec <- discr_rec %>%
-    step_impute_knn(carbon,
+    step_impute_knn(
+      carbon,
       nitrogen,
       impute_with = imp_vars(hydrogen, oxygen, nitrogen),
       neighbors = 3,
@@ -36,13 +37,17 @@ test_that("imputation values", {
     neighbors = rep(3, 2),
     id = ""
   )
-  expect_equal(as.data.frame(tidy(impute_rec, number = 2)), as.data.frame(imp_exp_un))
+  expect_equal(
+    as.data.frame(tidy(impute_rec, number = 2)),
+    as.data.frame(imp_exp_un)
+  )
   discr_rec <- prep(discr_rec, training = biomass_tr, verbose = FALSE)
   tr_data <- bake(discr_rec, new_data = biomass_tr)
   te_data <- bake(discr_rec, new_data = biomass_te) %>%
     dplyr::select(hydrogen, oxygen, nitrogen, carbon)
 
-  nn <- gower_topn(te_data[, c("hydrogen", "oxygen", "nitrogen")],
+  nn <- gower_topn(
+    te_data[, c("hydrogen", "oxygen", "nitrogen")],
     tr_data[, c("hydrogen", "oxygen", "nitrogen")],
     n = 3
   )$index
@@ -65,7 +70,6 @@ test_that("imputation values", {
     )
   }
 
-
   imp_exp_tr <- tidyr::crossing(
     terms = c("carbon", "nitrogen"),
     predictors = c("hydrogen", "oxygen", "nitrogen")
@@ -83,10 +87,12 @@ test_that("imputation values", {
 })
 
 test_that("All NA values", {
-  imputed <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
+  imputed <- recipe(
+    HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
     data = biomass_tr
   ) %>%
-    step_impute_knn(carbon,
+    step_impute_knn(
+      carbon,
       nitrogen,
       impute_with = imp_vars(hydrogen, oxygen, nitrogen),
       neighbors = 3
@@ -99,7 +105,8 @@ test_that("All NA values", {
 
 test_that("options", {
   rec_1 <- rec %>%
-    step_impute_knn(carbon,
+    step_impute_knn(
+      carbon,
       nitrogen,
       impute_with = imp_vars(hydrogen, oxygen, nitrogen),
       neighbors = 3,
@@ -109,7 +116,8 @@ test_that("options", {
   expect_equal(rec_1$steps[[1]]$options, list(nthread = 1, eps = 1e-08))
 
   rec_2 <- rec %>%
-    step_impute_knn(carbon,
+    step_impute_knn(
+      carbon,
       nitrogen,
       impute_with = imp_vars(hydrogen, oxygen, nitrogen),
       neighbors = 3,
@@ -119,7 +127,8 @@ test_that("options", {
   expect_equal(rec_2$steps[[1]]$options, list(nthread = 10, eps = 1e-08))
 
   rec_3 <- rec %>%
-    step_impute_knn(carbon,
+    step_impute_knn(
+      carbon,
       nitrogen,
       impute_with = imp_vars(hydrogen, oxygen, nitrogen),
       neighbors = 3,
@@ -130,37 +139,50 @@ test_that("options", {
 
   dat_1 <-
     tibble::tribble(
-      ~x, ~y,
-      1e-20, -0.135,
-      0.371, 1.775,
-      -0.399, 0.068,
-      -0.086, -0.511,
-      -1.094, -0.342,
-      -1.096, -0.812,
-      0.012, 0.937,
-      -0.89, -0.579,
-      -1.128, 0.14,
-      -1.616, 0.619
+      ~x,
+      ~y,
+      1e-20,
+      -0.135,
+      0.371,
+      1.775,
+      -0.399,
+      0.068,
+      -0.086,
+      -0.511,
+      -1.094,
+      -0.342,
+      -1.096,
+      -0.812,
+      0.012,
+      0.937,
+      -0.89,
+      -0.579,
+      -1.128,
+      0.14,
+      -1.616,
+      0.619
     )
   dat_1$x[1] <- 10^(-20)
 
   dat_2 <-
     tibble::tribble(
-      ~x, ~y,
-      -0.573, 0.922
+      ~x,
+      ~y,
+      -0.573,
+      0.922
     )
 
   ref_nn <- gower_topn(x = dat_2, y = dat_1, n = 2)$index
-  expect_snapshot(new_nn <- gower_topn(x = dat_2, y = dat_1, n = 2, eps = 2)$index)
+  expect_snapshot(
+    new_nn <- gower_topn(x = dat_2, y = dat_1, n = 2, eps = 2)$index
+  )
   expect_false(isTRUE(all.equal(ref_nn, new_nn)))
 })
 
-
-
 test_that("tunable", {
   rec <-
     recipe(~., data = iris) %>%
-    step_impute_knn(all_predictors())
+      step_impute_knn(all_predictors())
   rec_param <- tunable.step_impute_knn(rec$steps[[1]])
   expect_equal(rec_param$name, c("neighbors"))
   expect_true(all(rec_param$source == "recipe"))
@@ -210,9 +232,9 @@ test_that("error on wrong options argument", {
 test_that("bake method errors when needed non-standard role columns are missing", {
   imputed <-
     recipe(HHV ~ carbon + hydrogen + oxygen, data = biomass) %>%
-    step_impute_knn(carbon, impute_with = imp_vars(hydrogen, oxygen)) %>%
-    update_role(hydrogen, new_role = "potato") %>%
-    update_role_requirements(role = "potato", bake = FALSE)
+      step_impute_knn(carbon, impute_with = imp_vars(hydrogen, oxygen)) %>%
+      update_role(hydrogen, new_role = "potato") %>%
+      update_role_requirements(role = "potato", bake = FALSE)
 
   imputed_trained <- prep(imputed, training = biomass, verbose = FALSE)
 
@@ -265,10 +287,13 @@ test_that("empty selection tidy method works", {
 })
 
 test_that("printing", {
-  rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
-                data = biomass) %>%
+  rec <- recipe(
+    HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
+    data = biomass
+  ) %>%
     step_impute_knn(
-      carbon, nitrogen,
+      carbon,
+      nitrogen,
       impute_with = imp_vars(hydrogen, oxygen, nitrogen)
     )
 
@@ -290,7 +315,6 @@ test_that("tunable is setup to work with extract_parameter_set_dials", {
   expect_identical(nrow(params), 1L)
 })
 
-
 test_that("bad args", {
   expect_snapshot(
     recipe(~., data = mtcars) %>%
