@@ -6,33 +6,33 @@ iris_rec <- recipe(~., data = iris)
 test_that("basic usage", {
   rec <-
     iris_rec %>%
-    step_mutate(
-      dbl_width = Sepal.Width * 2,
-      half_length = Sepal.Length / 2
-    )
+      step_mutate(
+        dbl_width = Sepal.Width * 2,
+        half_length = Sepal.Length / 2
+      )
 
   prepped <- prep(rec, training = iris %>% slice(1:75))
 
   dplyr_train <-
     iris %>%
-    as_tibble() %>%
-    slice(1:75) %>%
-    mutate(
-      dbl_width = Sepal.Width * 2,
-      half_length = Sepal.Length / 2
-    )
+      as_tibble() %>%
+      slice(1:75) %>%
+      mutate(
+        dbl_width = Sepal.Width * 2,
+        half_length = Sepal.Length / 2
+      )
 
   rec_train <- bake(prepped, new_data = NULL)
   expect_equal(dplyr_train, rec_train)
 
   dplyr_test <-
     iris %>%
-    as_tibble() %>%
-    slice(76:150) %>%
-    mutate(
-      dbl_width = Sepal.Width * 2,
-      half_length = Sepal.Length / 2
-    )
+      as_tibble() %>%
+      slice(76:150) %>%
+      mutate(
+        dbl_width = Sepal.Width * 2,
+        half_length = Sepal.Length / 2
+      )
   rec_test <- bake(prepped, iris %>% slice(76:150))
   expect_equal(dplyr_test, rec_test)
 })
@@ -41,29 +41,27 @@ test_that("quasiquotation", {
   const <- 9.077
   rec_1 <-
     iris_rec %>%
-    step_mutate(new_var = Sepal.Width * const)
+      step_mutate(new_var = Sepal.Width * const)
 
   prepped_1 <- prep(rec_1, training = iris %>% slice(1:75))
 
   dplyr_train <-
     iris %>%
-    as_tibble() %>%
-    slice(1:75) %>%
-    mutate(new_var = Sepal.Width * const)
+      as_tibble() %>%
+      slice(1:75) %>%
+      mutate(new_var = Sepal.Width * const)
 
   rec_1_train <- bake(prepped_1, new_data = NULL)
   expect_equal(dplyr_train, rec_1_train)
 
   rec_2 <-
     iris_rec %>%
-    step_mutate(new_var = Sepal.Width * !!const)
+      step_mutate(new_var = Sepal.Width * !!const)
 
   prepped_2 <- prep(rec_2, training = iris %>% slice(1:75))
 
   rm(const)
-  expect_snapshot(error = TRUE,
-    prep(rec_1, training = iris %>% slice(1:75))
-  )
+  expect_snapshot(error = TRUE, prep(rec_1, training = iris %>% slice(1:75)))
   expect_no_error(
     prepped_2 <- prep(rec_2, training = iris %>% slice(1:75))
   )
@@ -109,7 +107,7 @@ test_that("tidying allows for named and unnamed expressions", {
 
 test_that("required_pkgs.step_mutate() works", {
   rec <- recipe(~., data = mtcars) %>%
-   step_mutate(new = 2)
+    step_mutate(new = 2)
 
   rec_pred <- prep(rec)
 
@@ -120,7 +118,7 @@ test_that("required_pkgs.step_mutate() works", {
     step_mutate(new = 2, .pkgs = "stats")
 
   rec_pred <- prep(rec)
- 
+
   expect_equal(required_pkgs(rec), c("recipes", "stats"))
   expect_equal(required_pkgs(rec_pred), c("recipes", "stats"))
 
@@ -132,7 +130,7 @@ test_that("required_pkgs.step_mutate() works", {
 
 test_that("step_mutate() .pkgs argument is backwards compatible", {
   rec <- recipe(~., data = mtcars) %>%
-   step_mutate(new = 2)
+    step_mutate(new = 2)
 
   rec$steps[[1]]$.pkgs <- NULL
 
@@ -142,12 +140,12 @@ test_that("step_mutate() .pkgs argument is backwards compatible", {
   expect_equal(required_pkgs(rec_pred), "recipes")
 
   rec <- recipe(~., data = mtcars) %>%
-   step_mutate(new = 2)
+    step_mutate(new = 2)
 
   rec_pred <- prep(rec)
-  
+
   rec_pred$steps[[1]]$.pkgs <- NULL
-  
+
   expect_equal(required_pkgs(rec), "recipes")
   expect_equal(required_pkgs(rec_pred), "recipes")
 })
