@@ -3,12 +3,14 @@ library(testthat)
 test_that("default option", {
   examples <- data.frame(
     times = lubridate::ymd_hms("2022-05-06 10:01:07") +
-      lubridate::hours(1:5) + lubridate::minutes(1:5) + lubridate::seconds(1:5)
+      lubridate::hours(1:5) +
+      lubridate::minutes(1:5) +
+      lubridate::seconds(1:5)
   )
 
   feats <- c("am", "hour", "hour12", "minute", "second", "decimal_day")
 
-  date_rec <- recipe(~ times, examples) %>%
+  date_rec <- recipe(~times, examples) %>%
     step_time(all_predictors(), features = feats)
 
   date_rec <- prep(date_rec, training = examples)
@@ -22,8 +24,11 @@ test_that("default option", {
     times_minute = lubridate::minute(examples$times),
     times_second = lubridate::second(examples$times),
     times_decimal_day = lubridate::hour(examples$times) +
-      (lubridate::second(examples$times) +
-       lubridate::minute(examples$times) * 60) / 3600
+      (
+        lubridate::second(examples$times) +
+          lubridate::minute(examples$times) * 60
+      ) /
+        3600
   )
   expect_equal(date_res, date_exp)
 })
@@ -31,12 +36,14 @@ test_that("default option", {
 test_that("returns integers", {
   examples <- data.frame(
     times = lubridate::ymd_hms("2022-05-06 10:01:07") +
-      lubridate::hours(1:5) + lubridate::minutes(1:5) + lubridate::seconds(1:5)
+      lubridate::hours(1:5) +
+      lubridate::minutes(1:5) +
+      lubridate::seconds(1:5)
   )
 
   feats <- c("hour", "hour12", "minute")
 
-  date_rec <- recipe(~ times, examples) %>%
+  date_rec <- recipe(~times, examples) %>%
     step_time(all_predictors(), features = feats, keep_original_cols = FALSE)
 
   date_rec <- prep(date_rec, training = examples)
@@ -45,15 +52,16 @@ test_that("returns integers", {
   expect_true(all(vapply(date_res, is.integer, logical(1))))
 })
 
-
 test_that("nondefault options", {
   examples <- data.frame(
     times = lubridate::ymd_hms("2022-05-06 10:01:07") +
-      lubridate::hours(1:5) + lubridate::minutes(1:5) + lubridate::seconds(1:5)
+      lubridate::hours(1:5) +
+      lubridate::minutes(1:5) +
+      lubridate::seconds(1:5)
   )
 
-  date_rec <- recipe(~ times, examples) %>%
-    step_time(all_predictors(), features = c( "minute", "second"))
+  date_rec <- recipe(~times, examples) %>%
+    step_time(all_predictors(), features = c("minute", "second"))
 
   date_rec <- prep(date_rec, training = examples)
   date_res <- bake(date_rec, new_data = examples)
@@ -73,8 +81,8 @@ test_that("custom hour12 metric is correct", {
       lubridate::seconds(seq(0, 60 * 60 * 24))
   )
 
-  date_rec <- recipe(~ time, full_day) %>%
-    step_time(all_predictors(), features = c( "hour12"))
+  date_rec <- recipe(~time, full_day) %>%
+    step_time(all_predictors(), features = c("hour12"))
 
   date_rec <- prep(date_rec, training = full_day)
   date_res <- bake(date_rec, new_data = full_day)
@@ -98,7 +106,7 @@ test_that("check_name() is used", {
   )
   dat$time_hour <- dat$time
 
-  rec <- recipe(~ ., data = dat) %>%
+  rec <- recipe(~., data = dat) %>%
     step_time(time)
 
   expect_snapshot(
@@ -110,12 +118,14 @@ test_that("check_name() is used", {
 test_that("errors on wrong values of features", {
   examples <- data.frame(
     times = lubridate::ymd_hms("2022-05-06 10:01:07") +
-      lubridate::hours(1:5) + lubridate::minutes(1:5) + lubridate::seconds(1:5)
+      lubridate::hours(1:5) +
+      lubridate::minutes(1:5) +
+      lubridate::seconds(1:5)
   )
 
   expect_snapshot(
     error = TRUE,
-    recipe(~ times, examples) %>%
+    recipe(~times, examples) %>%
       step_time(all_predictors(), features = "hourly") %>%
       prep()
   )
@@ -126,7 +136,9 @@ test_that("errors on wrong values of features", {
 test_that("bake method errors when needed non-standard role columns are missing", {
   examples <- data.frame(
     times = lubridate::ymd_hms("2022-05-06 10:01:07") +
-      lubridate::hours(1:5) + lubridate::minutes(1:5) + lubridate::seconds(1:5)
+      lubridate::hours(1:5) +
+      lubridate::minutes(1:5) +
+      lubridate::seconds(1:5)
   )
 
   feats <- c("am", "hour", "hour12", "minute", "second", "decimal_day")
@@ -181,12 +193,14 @@ test_that("empty selection tidy method works", {
 test_that("keep_original_cols works", {
   examples <- data.frame(
     times = lubridate::ymd_hms("2022-05-06 10:01:07") +
-      lubridate::hours(1:5) + lubridate::minutes(1:5) + lubridate::seconds(1:5)
+      lubridate::hours(1:5) +
+      lubridate::minutes(1:5) +
+      lubridate::seconds(1:5)
   )
 
   new_names <- c("times_hour", "times_minute", "times_second")
 
-  rec <- recipe(~ times, examples) %>%
+  rec <- recipe(~times, examples) %>%
     step_time(all_predictors(), keep_original_cols = FALSE)
 
   rec <- prep(rec)
@@ -197,7 +211,7 @@ test_that("keep_original_cols works", {
     new_names
   )
 
-  rec <- recipe(~ times, examples) %>%
+  rec <- recipe(~times, examples) %>%
     step_time(all_predictors(), keep_original_cols = TRUE)
 
   rec <- prep(rec)
@@ -212,10 +226,12 @@ test_that("keep_original_cols works", {
 test_that("keep_original_cols - can prep recipes with it missing", {
   examples <- data.frame(
     times = lubridate::ymd_hms("2022-05-06 10:01:07") +
-      lubridate::hours(1:5) + lubridate::minutes(1:5) + lubridate::seconds(1:5)
+      lubridate::hours(1:5) +
+      lubridate::minutes(1:5) +
+      lubridate::seconds(1:5)
   )
 
-  rec <- recipe(~ times, examples) %>%
+  rec <- recipe(~times, examples) %>%
     step_time(all_predictors())
 
   rec$steps[[1]]$keep_original_cols <- NULL
@@ -232,10 +248,12 @@ test_that("keep_original_cols - can prep recipes with it missing", {
 test_that("printing", {
   examples <- data.frame(
     times = lubridate::ymd_hms("2022-05-06 10:01:07") +
-      lubridate::hours(1:5) + lubridate::minutes(1:5) + lubridate::seconds(1:5)
+      lubridate::hours(1:5) +
+      lubridate::minutes(1:5) +
+      lubridate::seconds(1:5)
   )
 
-  rec <- recipe(~ times, examples) %>%
+  rec <- recipe(~times, examples) %>%
     step_time(all_predictors())
 
   expect_snapshot(print(rec))
